﻿using System;
using System.Linq;
using System.Web.Mvc;
using KendoGridMvcCodeFirst.Models;
using KendoGridMvcCodeFirst.ViewModels;
using Kendo.Mvc.Extensions;
using Kendo.Mvc.UI;

namespace CodeFirstEF.Controllers
{
    public class HomeController : Controller
    {
        CustomerContext dbContext = new CustomerContext();

        public ActionResult Index()
        {
            ViewBag.Message = "Welcome to ASP.NET MVC!";           
            return View();
        }

        public ActionResult GetCustomers([DataSourceRequest] DataSourceRequest request)
        {
            return Json(GetCustomerViewModels().ToDataSourceResult(request));
        }

        public ActionResult UpdateCustomer([DataSourceRequest] DataSourceRequest request, Customer customer)
        {
            var customerToUpdate = dbContext.Customers.First(cust => cust.CustomerID == customer.CustomerID);

            TryUpdateModel(customerToUpdate);

            dbContext.SaveChanges();

            return Json(ModelState.ToDataSourceResult());
        }

        public ActionResult InsertCustomer([DataSourceRequest] DataSourceRequest request, Customer customerToAdd)
        {
            if (ModelState.IsValid)
            {
                dbContext.Customers.Add(customerToAdd);
                dbContext.SaveChanges();
            }

            return Json(new [] { customerToAdd }.ToDataSourceResult(request));
        }

        public ActionResult DeleteCustomer([DataSourceRequest] DataSourceRequest request, Customer customer)
        {
            var customerToDelete = dbContext.Customers.First(cust => cust.CustomerID == customer.CustomerID);

            if (customerToDelete!=null)
            {
                dbContext.Customers.Remove(customerToDelete);
                dbContext.SaveChanges();
            }

            return Json(new [] { customerToDelete }.ToDataSourceResult(request));
        }

        private IQueryable<CustomerViewModel> GetCustomerViewModels()
        {
            return dbContext.Customers
                            .Select(
                            c => new CustomerViewModel
                            {
                                CustomerID = c.CustomerID,
                                Name = c.Name,
                                Email=c.Email,
                                Phone=c.Phone
                            });
        }
    }
}
